% MtOpenRelationshipsStream initializes the stream of all relationships of an object. 
%
%   [status, stream] = MtOpenRelationshipsStream (object);
%
%   The function opens the relationship stream on the specified object. The function 
%   MtNextProperty will use the stream to provide the user with the different  
%   relationships of the object.
%
%   Note that the function MtGetAllRelationships retrieves all the relationships  
%   possible for an instance of a given class. MtGetAllRelationships works at the 
%   schema level, while MtOpenRelationshipsStream works at the data level.
%
%   The  function can be called either inside a transaction or during version access.
%
%   OUTPUT [2]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      stream: number
%          A relationship stream.
%
%   INPUT [1]
%
%     object: number
%           The key to an object.
%
%   See also: 
%      MtGetAllRelationships
%      MtCloseStream
%      MtNextProperty
%
%   Example:
%
% conn = MtCurrentConnection;
%
% if ~conn
%    [status, conn] = MtAllocateConnection;
%    status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%    status = MtSetCurrentConnection (conn);
% end
% 
% status = MtStartVersionAccess;
% 
% [status, stream] = MtOpenInstancesStream ('Movie', 1);
% [status, instance1] = MtNextObject (stream);
% status = MtCloseStream (stream);
%
% [status, type, typesize] = ...
%     MtGetValue (instance1, 'Title', 1, 0, 0, 1, 0);
% [status, type, title, typesize] = ...
%     MtGetValue (instance1, 'Title', type, 1, 0, typesize, 0);
%              
% [status, stream] = MtOpenRelationshipsStream (instance1);
% [status, relation, flag] = MtNextProperty (stream);
% status = MtCloseStream (stream);
%
% if flag
%    [status, type, typesize] = ...
%        MtGetValue (relation,'Mt Name', 1, 0, 0, 1, 0);
%    [status, type, value, typesize] = ...
%        MtGetValue (relation,'Mt Name', type, 1, 0, typesize, 0);
%              
%    fprintf ('"%s" has the relationship "%s"\n', title, value);
%              
%    [status, stream] = MtOpenSuccessorsStream (instance1, relation);
%    [status, successor] = MtNextObject (stream);
%    status = MtCloseStream (stream);
%       
%    [status, flag] = MtIsInstanceOf (successor, 'MovieDirector');
%    if flag
%       [status, type, typesize] = ...
%           MtGetValue (successor,'LastName', 1, 0, 0, 1, 0);
%       [status, type, name, typesize] = ...
%           MtGetValue (successor,'LastName', type, 1, 0, typesize, 0);
%              
%       fprintf ('The movie "%s" was directed by "%s"\n', bookTitle);
%    end     
% else
%    fprintf ('"%s" has NO instantiated relationships\n', title); 
% end  
%
% status = MtEndVersionAccess; 
%
% status = MtNoCurrentConnection;
% status = MtDisconnectDatabase (conn);
% status = MtFreeConnection (conn);

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

