% MtSetValue updates an attribute with a new value.
%
%   status = MtSetValue (object, attribute, type, value);
%   status = MtSetValue (object, attribute, type, value, rank, dimension(1:rank));
%
%   The value of the attribute is modified, the entry-point is updated if 
%   there is an entry-point function, the entries for the object in any index 
%   attached to the class are updated.
%
%   Modifications are checked during MtCommitTransaction only, unless otherwise 
%   requested by the user beforehand, using the functions MtCheckObject, 
%   MtCheckProperty, or MtCheckAttribute.
%
%   Entry points and the name of attributes are not case sensitive.
%
%   This function can be called either inside a transaction or during version access.
%
%   OUTPUT [1]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%   INPUT [4]
%
%      object: number
%          The key to an object. 
%
%      attribute: number or string
%          The key or the name of an attribute.
%
%      type: number or string
%          The expected type of the list value. Currently implemented:
%		        MT_FLOAT
%             MT_DOUBLE
%             MT_S16
%             MT_S32
%             MT_KEY
%             MT_ASCII_CHAR
%             MT_CHAR
%             MT_NIL
%             MT_ASCII_STRING
%             MT_STRING
%             MT_TIMESTAMP
%             MT_S32_LIST:
%             MT_U8_LIST:
%             MT_S16_LIST:
%             MT_U16_LIST:
%             MT_U32_LIST:
%             MT_FLOAT_LIST:
%             MT_DOUBLE_LIST
%
%      value: number or string
%          The value to be stored.        
%
%      rank: number
%          The number of dimensions of the value. 
%
%          The number of dimensions of a value is equal to 1 for the MT_*_LIST types 
%          when the stored value is not NULL, equal to 0 otherwise. It can range from 
%          1 to 8 for the MT_*_ARRAY types when the stored value is not NULL, equal to 
%          0 otherwise. For all other types the rank is always 0.
% 
%          For MT_*_ARRAY types more arguments are required, but these types are
%          not implemented yet.
%
%      dimension(i): number
%          The number of elements of the ith row. 

%  Example:
%
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'arches00.wins.uva.nl', 'VideoStore');
%   status = MtSetCurrentConnection (conn);
%   status = MtStartTransaction (7);
%   [status, stream] = MtOpenInstancesStream('Movie', 1);
%   [status, object] = MtNextObject (stream);
%
%   status = MtSetValue (object, 'RunningTime', 'MT_S32', 140, 0); 
%   status = MtSetValue (object, 'Preview', 'MT_U8_LIST', [1 2 3], 1, 3); 
%
%   status = MtCloseStream (stream);
%   status = MtCommitTransaction;
%   status = MtNoCurrentConnection;
%   status = MtDisconnectDatabase (conn);
%   status = MtFreeConnection (conn);
%
% See also:
%
%   MtSetListElements 
%   MtGetValue
%   MtRemoveValue

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 5.3.0.10183 (R11) - Matisse 4.3
%   Author:  Arnoud Visser <arnoud@wins.uva.nl>
%   Date:    January 2001